@@ -102,13 +102,6 @@ func main() {
 		},
 	}
 
-	gocodeFlags := []cli.Flag{
-		&cli.BoolFlag{
-			Name:  "godeps-to-tree",
-			Usage: "output Go program to convert Go package dependency list to tree.",
-		},
-	}
-
 	green := color.New(color.FgHiGreen).SprintFunc()
 
 	app := &cli.App{
@@ -161,14 +154,6 @@ func main() {
 				Before:  notExistArgs,
 				Action:  actionWeb,
 			},
-			{
-				Name:    "gocode",
-				Aliases: []string{"gc", "code"},
-				Usage:   "Outputs a sample Go program calling \"gtree\" package.",
-				Flags:   gocodeFlags,
-				Before:  notExistArgs,
-				Action:  actionGoCode,
-			},
 			{
 				Name:    "version",
 				Aliases: []string{"v"},
@@ -311,10 +296,3 @@ func actionWeb(c *cli.Context) error {
 	fmt.Printf("See: %s\n", treeMakerURL)
 	return nil
 }
-
-func actionGoCode(c *cli.Context) error {
-	if c.Bool("godeps-to-tree") {
-		return goDependencesToTree.println()
-	}
-	return findToTree.println()
-}
