@@ -5,6 +5,7 @@ package gtree
 import (
 	"context"
 	"io"
+	"iter"
 
 	"github.com/fatih/color"
 	"golang.org/x/sync/errgroup"
@@ -183,6 +184,11 @@ func (t *treePipeline) walkProgrammably(root *Node, callback func(*WalkerNode) e
 	return t.handlePipelineErr(ctx, errcg, errcw)
 }
 
+// no implemented
+func (t *treePipeline) walkIterProgrammably(root *Node, cfg *config) iter.Seq2[*WalkerNode, error] {
+	return nil
+}
+
 // 関心事は各ノードの枝の形成
 type growerPipeline interface {
 	grow(context.Context, <-chan *Node) (<-chan *Node, <-chan error)
